@@ -16,5 +16,5 @@
 ## along with this program; if not, a copy is available at
 ## https://www.R-project.org/Licenses/GPL-2
 
-rtgamma=function(shape, rate, a) .Call("crtgamma", shape, rate, a)
+rtgamma=function(n, shape, rate, a) .Call("crtgamma", n, shape, rate, a)
 
