@@ -1,7 +1,7 @@
 /*
  *  BART: Bayesian Additive Regression Trees
- *  Copyright (C) 2017 Robert McCulloch and Rodney Sparapani
- *
+ *  Copyright (C) 2017-2018 Robert McCulloch, Rodney Sparapani
+ *                          and Charles Spanbauer
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -52,8 +52,19 @@ public:
    void setpi(pinfo& pi) {this->pi = pi;}
    void setprior(double alpha, double beta, double tau)
       {pi.alpha=alpha; pi.mybeta = beta; pi.tau=tau;}
-   void setdart(double _a, double _b, double _rho, bool _aug, bool _dart)
-      {this->a=_a; this->b=_b; this->rho=_rho; this->aug=_aug; this->dart=_dart;}
+   void setdart(double _a, double _b, double _rho, bool _aug, bool _dart, 
+		double _theta=0., double _omega=1.) {
+     this->a=_a; this->b=_b; this->rho=_rho; this->aug=_aug; 
+     this->dart=_dart; this->omega=_omega; 
+     if(_theta==0.){
+       this->const_theta=false;
+       this->theta=1.;
+     }
+     else{
+       this->const_theta=true;
+       this->theta=_theta;
+     }
+}
    void startdart() {this->dartOn=!(this->dartOn);}
    void settau(double tau) {pi.tau=tau;}
    tree& gettree(size_t i ) { return t[i];}
@@ -61,6 +72,7 @@ public:
    void setxinfo(xinfo& _xi);
    std::vector<size_t>& getnv() {return nv;}
    std::vector<double>& getpv() {return pv;}
+   double gettheta() {return theta;}
    //------------------------------
    //public methods
    void birth(size_t i, size_t nid,size_t v, size_t c, double ml, double mr)
@@ -71,7 +83,7 @@ public:
    void tonull() {for(size_t i=0;i!=t.size();i++) t[i].tonull();}
    void predict(size_t p, size_t n, double *x, double *fp);
    void draw(double sigma, rn& gen);
-   void draw_s(rn& gen);
+//   void draw_s(rn& gen);
    double f(size_t i) {return allfit[i];}
 protected:
    size_t m;  //number of trees
@@ -86,10 +98,10 @@ protected:
    double *r;
    double *ftemp;
    dinfo di;
-   bool dart,dartOn,aug;
-   double a,b,rho,const_alpha;
+   bool dart,dartOn,aug,const_theta;
+   double a,b,rho,theta,omega;
    std::vector<size_t> nv;
-   std::vector<double> pv;
+   std::vector<double> pv, lpv;
 };
 
 #endif
